SendTimeoutError

Enum SendTimeoutError 

pub enum SendTimeoutError<T> {
    Timeout(T),
    Disconnected(T),
}
๐Ÿ”ฌThis is a nightly-only experimental API. (mpmc_channel #126840)
An error returned from the send_timeout method.

The error contains the message being sent so it can be recovered.

Variants



Timeout(T)

๐Ÿ”ฌThis is a nightly-only experimental API. (mpmc_channel #126840)

The message could not be sent because the channel is full and the operation timed out.

If this is a zero-capacity channel, then the error indicates that there was no receiver available to receive the message and the operation timed out.



Disconnected(T)

๐Ÿ”ฌThis is a nightly-only experimental API. (mpmc_channel #126840)

The message could not be sent because the channel is disconnected.